/* 
 *	HT Editor
 *	analyinfo.h
 *
 *	Copyright (C) 1999-2002 Sebastian Biallas (sb@web-productions.de)
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License version 2 as
 *	published by the Free Software Foundation.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef ANALYINFO_H
#define ANALYINFO_H

#define htanalyser_name "ht-analyser"
#define htanalyser_copyright "(c) 1999-2002 "htanalyser_author" ("htanalyser_mail")"
#define htanalyser_loadtitle htanalyser_name" "htanalyser_copyright

#define htanalyser_author "Sebastian Biallas"
#define htanalyser_mail "sb@biallas.net"

#endif
